==> 3.4.1.tar.gz: xbackbone/resources/lang/ja.lang.php <==
<?php
return [
    'lang' => 'Japanese',
    'enforce_language' => '言語設定',
    'yes' => 'はい',
    'no' => 'いいえ',
    'send' => '送信',
    'no_media' => 'メディアが見つかりません。',
    'login.username' => 'ユーザー名または電子メール',
    'password' => 'パスワード',
    'login' => 'ログイン',
    'username' => 'ユーザー名',
    'home' => 'ホーム',
    'users' => 'ユーザー',
    'system' => 'システム',
    'profile' => 'プロフィール',
    'logout' => 'ログアウト',
    'pager.next' => '次へ',
    'pager.previous' => '戻る',
    'copy_link' => 'リンクをコピー',
    'public.telegram' => 'Telegramにシェア',
    'public.delete_text' => '本当に削除しますか？この操作は元に戻せません。',
    'preview' => 'プレビュー',
    'filename' => 'ファイル名',
    'size' => 'サイズ',
    'public' => '公開',
    'owner' => '所有者',
    'date' => '日付',
    'raw' => 'ファイルのみを表示',
    'download' => 'ダウンロード',
    'upload' => 'アップロード',
    'delete' => '削除',
    'publish' => '公開する',
    'hide' => '非公開にする',
    'files' => 'ファイル',
    'orphaned_files' => '所有者のいないファイル',
    'theme' => 'テーマ',
    'click_to_load' => 'クリックしてロード...',
    'apply' => '適用',
    'save' => '保存',
    'system_info' => 'システム情報',
    'user.create' => 'ユーザーを追加',
    'user.edit' => 'ユーザーを編集',
    'is_active' => 'アクティブ',
    'is_admin' => '管理者',
    'your_profile' => 'あなたのプロフィール',
    'token' => 'トークン',
    'copy' => 'コピー',
    'update' => '更新',
    'edit' => '編集',
    'client_config' => 'クライアント設定',
    'user_code' => 'ユーザーコード',
    'active' => 'アクティブ',
    'admin' => '管理者',
    'reg_date' => '登録日',
    'none' => 'None',
    'open' => '開く',
    'confirm' => '確認',
    'confirm_string' => '本当によろしいですか？',
    'installed' => 'インストールが正常に完了しました！',
    'bad_login' => 'ユーザー名またはパスワードが違います。',
    'account_disabled' => 'あなたのアカウントは無効化されています。',
    'welcome' => 'ようこそ、 %sさん！',
    'goodbye' => 'さようなら！',
    'token_not_found' => '指定されたトークンが見つかりません。',
    'email_required' => '電子メール アドレスが必要です。',
    'email_taken' => '電子メール アドレスは既に使用されています。',
    'username_required' => 'ユーザー名が必要です。',
    'username_taken' => '入力されたユーザー名はすでに使用されています。',
    'password_required' => 'パスワードが必要です。',
    'user_created' => 'ユーザー 「%s」 が作成されました！',
    'user_updated' => 'ユーザー 「%s」 が更新されました！',
    'profile_updated' => 'プロフィールは正常に更新されました！',
    'user_deleted' => 'ユーザーが削除されました。',
    'cannot_delete' => '自分自身を削除することはできません。',
    'drop_to_upload' => 'クリックまたはファイルをここにドロップしてアップロード。',
    'prerelease_channel' => 'プレリリースチャンネル',
    'auto_set' => '自動で設定',
    'maintenance_in_progress' => '只今メンテナンス中です。 しばらくお待ち下さい...',
    'upgrade' => 'アップグレード',
    'file_size_no_match' => 'ダウンロードしたファイルのサイズが正しくありません。',
    'new_version_available' => '新しいバージョン %s が利用可能です！',
    'path_not_writable' => '出力先は書き込み可能ではありません。',
    'maintenance' => 'メンテナンス',
    'time' => '時間',
    'dotted_search' => '検索...',
    'gallery' => 'ギャラリー',
    'deleted_orphans' => '所有者のいないファイルを %d 個 削除しました。',
    'cannot_demote' => '自分自身を降格させることはできません。',
    'system_settings' => 'システム設定',
    'php_info' => 'PHPの情報',
    'used' => '使用済み',
];

==> 3.6.2.tar.gz: xbackbone/resources/lang/ja.lang.php <==
<?php
return [
    'lang' => 'Japanese',
    'enforce_language' => '言語設定',
    'yes' => 'はい',
    'no' => 'いいえ',
    'send' => '送信',
    'no_media' => 'メディアが見つかりません。',
    'login.username' => 'ユーザー名または電子メール',
    'password' => 'パスワード',
    'login' => 'ログイン',
    'username' => 'ユーザー名',
    'home' => 'ホーム',
    'users' => 'ユーザー',
    'system' => 'システム',
    'profile' => 'プロフィール',
    'logout' => 'ログアウト',
    'pager.next' => '次へ',
    'pager.previous' => '戻る',
    'copy_link' => 'リンクをコピー',
    'public.telegram' => 'Telegramにシェア',
    'public.delete_text' => '本当に削除しますか？この操作は元に戻せません。',
    'preview' => 'プレビュー',
    'filename' => 'ファイル名',
    'size' => 'サイズ',
    'public' => '公開',
    'owner' => '所有者',
    'date' => '日付',
    'raw' => 'ファイルのみを表示',
    'download' => 'ダウンロード',
    'upload' => 'アップロード',
    'delete' => '削除',
    'publish' => '公開する',
    'hide' => '非公開にする',
    'files' => 'ファイル',
    'orphaned_files' => '所有者のいないファイル',
    'theme' => 'テーマ',
    'click_to_load' => 'クリックしてロード…',
    'apply' => '適用',
    'save' => '保存',
    'system_info' => 'システム情報',
    'user.create' => 'ユーザーを追加',
    'user.edit' => 'ユーザーを編集',
    'is_active' => 'アクティブ',
    'is_admin' => '管理者',
    'your_profile' => 'あなたのプロフィール',
    'token' => 'トークン',
    'copy' => 'コピー',
    'update' => '更新',
    'edit' => '編集',
    'client_config' => 'クライアント設定',
    'user_code' => 'ユーザーコード',
    'active' => 'アクティブ',
    'admin' => '管理者',
    'reg_date' => '登録日',
    'none' => 'None',
    'open' => '開く',
    'confirm' => '確認',
    'confirm_string' => '本当によろしいですか？',
    'installed' => 'インストールが正常に完了しました！',
    'bad_login' => 'ユーザー名またはパスワードが違います。',
    'account_disabled' => 'あなたのアカウントは無効化されています。',
    'welcome' => 'ようこそ、 %sさん！',
    'goodbye' => 'さようなら！',
    'token_not_found' => '指定されたトークンが見つかりません。',
    'email_required' => '電子メール アドレスが必要です。',
    'email_taken' => '電子メール アドレスは既に使用されています。',
    'username_required' => 'ユーザー名が必要です。',
    'username_taken' => '入力されたユーザー名はすでに使用されています。',
    'password_required' => 'パスワードが必要です。',
    'user_created' => 'ユーザー 「%s」 が作成されました！',
    'user_updated' => 'ユーザー 「%s」 が更新されました！',
    'profile_updated' => 'プロフィールは正常に更新されました！',
    'user_deleted' => 'ユーザーが削除されました。',
    'cannot_delete' => '自分自身を削除することはできません。',
    'drop_to_upload' => 'クリックまたはファイルをここにドロップしてアップロード。',
    'prerelease_channel' => 'プレリリースチャンネル',
    'auto_set' => '自動で設定',
    'maintenance_in_progress' => '只今メンテナンス中です。 しばらくお待ち下さい...',
    'upgrade' => 'アップグレード',
    'file_size_no_match' => 'ダウンロードしたファイルのサイズが正しくありません。',
    'new_version_available' => '新しいバージョン %s が利用可能です！',
    'path_not_writable' => '出力先は書き込み可能ではありません。',
    'maintenance' => 'メンテナンス',
    'time' => '時間',
    'dotted_search' => '検索...',
    'gallery' => 'ギャラリー',
    'deleted_orphans' => '所有者のいないファイルを %d 個 削除しました。',
    'cannot_demote' => '自分自身を降格させることはできません。',
    'system_settings' => 'システム設定',
    'php_info' => 'PHPの情報',
    'used' => '使用済み',
    'switch_to' => '転換する：',
    'table' => 'テーブル形',
    'name' => 'ファイル名順',
    'clean_orphaned_uploads' => '所有者のないファイルを削除',
    'already_latest_version' => 'もうすでに最新のXbackboneを使っています。',
    'check_for_updates' => '更新を確認',
    'updates' => '更新内容',
    'cancel' => 'キャンセル',
    'default_lang_behavior' => 'Xbackboneで使用者のブラウザの言語を自動的に検索（Defaultは英語）.',
    'donation' => '支援',
    'donate_text' => '支援も受け入れていますので、Xbackboneが気に入った場合、よろしくお願いいたします！',
    'custom_head_html' => 'HTML Headのコンテンツをカスタマイズ',
    'register_enabled' => '登録を活性化',
    'order_by' => '…順',
    'custom_head_set' => 'HTML Headのカスタマイズが適用されました。',
    'copied' => 'コピーしました！',
    'custom_head_html_hint' => 'この部分に入力した内容は全てのページの<head></head>の中に入ります.',
    'remember_me' => 'ログイン情報を保存',
    'please_wait' => '少々お待ちください…',
    'dont_close' => '作業を完了する前にはこのタブを閉じないでください。',
    'no_upload_token' => 'アップロードのための個人トークンがありません。（まず新しく生成してもう一度試してください）',
];
